<?php

namespace Nutrition_Facts_Label_Creator_El\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Utils;
use Elementor\Scheme_Color;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Background;

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}


class Widget_Nutrition_Facts_Label_Creator_El extends Widget_Base {

    public function get_name() {
        return 'nutrition-facts-label-creator-el';
    }

    public function get_title() {
        return esc_html__( 'Nutrition Facts Label Creator', 'nflc_el' );
    }

    public function get_icon() {
        return 'eicon-table';
    }

    /**
     * Get widget keywords.
     *
     * Retrieve the list of keywords the widget belongs to.
     *
     * @since 2.1.0
     * @access public
     *
     * @return array Widget keywords.
     */
    public function get_keywords() {
        return [ 'nutrition', 'food', 'nutrition facts', 'nutrition table', 'nutrition label' ];
    }

    protected function register_controls() {

        $this->start_controls_section(
            'section_general',
            [
                'label' => __( 'General', 'nflc_el' ),
            ]
        );

    $this->add_control(
        'display_style',
        [
            'label' => esc_html__( 'Nutrition table style', 'nflc_el' ),
            'type' => Controls_Manager::SELECT,
            'options' => [
            'std' => __( 'Standard', 'nflc_el' ),
            'classic' => __( 'Classic', 'nflc_el' ),
            'classic tabular' => __( 'Classic Tabular', 'nflc_el' ),
            'flat' => __( 'Flat', 'nflc_el' ),
            'flat striped' => __( 'Flat Striped', 'nflc_el' ),
            'lined' => __( 'Lined', 'nflc_el' ),
        ],
        'default' => 'std',
        'description' => esc_html__( 'Select a style for Nutrition table.', 'nflc_el' ),
        ]
    );

    $this->add_control(
        'nutri_heading',
        [
            'label' => esc_html__( 'Nutrition Table Heading', 'nflc_el' ),
            'type' => Controls_Manager::TEXT,
            'dynamic' => [
                'active' => true,
            ],
            'default' => esc_html__( 'Nutrition Facts', 'nflc_el' )
        ]
    );

    $this->add_control(
        'show_dv',
        [
            'type' => Controls_Manager::SWITCHER,
            'label' => esc_html__( 'Show standard Daily Values', 'nflc_el' ),
            'default' => '',
            'label_on' => __( 'On', 'nflc_el' ),
            'label_off' => __( 'Off', 'nflc_el' ),
            'return_value' => 'true',
            'description' => esc_html__( 'Enabling this option will show standard Daily Values in the chart.', 'nflc_el' ),
        ]
    );

    $this->add_control(
        'extra_notes',
        [
            'label' => esc_html__( 'Nutrition label extra notes', 'nflc_el' ),
            'type' => Controls_Manager::TEXTAREA,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '* The % Daily Value (DV) tells you how much a nutrient in a serving of food contributes to a daily diet. 2,000 calories a day is used for general nutrition advice.',
            'description' => esc_html__( 'Provide extra notes for the Nutrition table. This will be displayed at the end of table.', 'nflc_el' ),
        ]
    );

    $this->end_controls_section();

    $this->start_controls_section(
        'section_nutrients',
        [
            'label' => __('Nutrients & Meta', 'nflc_el')
        ]
    );

    $this->add_control(
        'serving_size',
        [
            'label' => esc_html__( 'Serving Size', 'nflc_el' ),
            'type' => Controls_Manager::TEXT,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'description' => esc_html__( 'Provide a serving size. E.g. 1 Cookie(20g), or 100g', 'nflc_el' )
        ]
    );

    $this->add_control(
        'calories',
        [
            'label' => esc_html__( 'Calories per serving (cal)', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'Provide approximate calories (without unit) per serving. E.g. 240', 'nflc_el' )
        ]
    ); 

    $this->add_control(
        'serving_per_cont',
        [
            'label' => esc_html__( 'Serving Per Container', 'nflc_el' ),
            'type' => Controls_Manager::TEXT,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'Provide serving per container. E.g. 30', 'nflc_el' )
        ]
    );    

    $this->add_control(
        'total_fat',
        [
            'label' => esc_html__( 'Total Fat', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Total Fat (g), without unit. Standard daily value is 78 g', 'nflc_el' )
        ]
    );

    $this->add_control(
        'saturated_fat',
        [
            'label' => esc_html__( 'Saturated Fat', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Saturated Fat (g), without unit. Standard daily value is 20 g', 'nflc_el' )
        ]
    );

    $this->add_control(
        'trans_fat',
        [
            'label' => esc_html__( 'Trans Fat', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Trans Fat (g), without unit. ', 'nflc_el' )
        ]
    );

    $this->add_control(
        'polyunsat_fat',
        [
            'label' => esc_html__( 'Polyunsaturated Fat', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Polyunsaturated Fat (g), without unit. ', 'nflc_el' )
        ]
    );

    $this->add_control(
        'monounsat_fat',
        [
            'label' => esc_html__( 'Monounsaturated Fat', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Monounsaturated Fat (g), without unit. ', 'nflc_el' )
        ]
    );

    $this->add_control(
        'cholesterol',
        [
            'label' => esc_html__( 'Cholesterol', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Cholesterol (mg), without unit. Standard daily value is 300 mg', 'nflc_el' )
        ]
    );

    $this->add_control(
        'sodium',
        [
            'label' => esc_html__( 'Sodium', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Sodium (mg), without unit. Standard daily value is 2300 mg', 'nflc_el' )
        ]
    );

    $this->add_control(
        'carbohydrate',
        [
            'label' => esc_html__( 'Total Carbohydrate', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Total Carbohydrate (g), without unit. Standard daily value is 275 g', 'nflc_el' )
        ]
    );

    $this->add_control(
        'fiber',
        [
            'label' => esc_html__( 'Dietary Fiber', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Dietary Fiber (g), without unit. Standard daily value is 28 g', 'nflc_el' )
        ]
    );

    $this->add_control(
        'sugar',
        [
            'label' => esc_html__( 'Total Sugars', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Total Sugars (g), without unit. ', 'nflc_el' )
        ]
    );

    $this->add_control(
        'added_sugar',
        [
            'label' => esc_html__( 'Added Sugars', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Added Sugars (g), without unit. Standard daily value is 50 g', 'nflc_el' )
        ]
    );

    $this->add_control(
        'sugar_alcohal',
        [
            'label' => esc_html__( 'Sugar Alcohal', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Sugar Alcohal (g), without unit. ', 'nflc_el' )
        ]
    );

    $this->add_control(
        'protein',
        [
            'label' => esc_html__( 'Protein', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Protein (g), without unit. Standard daily value is 50 g', 'nflc_el' )
        ]
    );

    $this->add_control(
        'vitamin_d',
        [
            'label' => esc_html__( 'Vitamin D (Cholecalciferol)', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Vitamin D (Cholecalciferol) (IU), without unit. Standard daily value is 800 IU (International Units) or 20 mcg', 'nflc_el' )
        ]
    );

    $this->add_control(
        'calcium',
        [
            'label' => esc_html__( 'Calcium', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Calcium (mg), without unit. Standard daily value is 1300 mg', 'nflc_el' )
        ]
    );

    $this->add_control(
        'iron',
        [
            'label' => esc_html__( 'Iron', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Iron (mg), without unit. Standard daily value is 18 mg', 'nflc_el' )
        ]
    );

    $this->add_control(
        'potassium',
        [
            'label' => esc_html__( 'Potassium', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Potassium (mg), without unit. Standard daily value is 4700 mg', 'nflc_el' )
        ]
    );

    $this->add_control(
        'vitamin_a',
        [
            'label' => esc_html__( 'Vitamin A', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Vitamin A (International Units), without unit. Standard daily value is 900 mcg', 'nflc_el' )
        ]
    );

    $this->add_control(
        'vitamin_c',
        [
            'label' => esc_html__( 'Vitamin C (Ascorbic Acid)', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Vitamin C (Ascorbic Acid) (mg), without unit. Standard daily value is 90 mg', 'nflc_el' )
        ]
    );

    $this->add_control(
        'vitamin_e',
        [
            'label' => esc_html__( 'Vitamin E (Tocopherol)', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Vitamin E (Tocopherol) (IU), without unit. Standard daily value is 33 IU or 15 mg', 'nflc_el' )
        ]
    );

    $this->add_control(
        'vitamin_k',
        [
            'label' => esc_html__( 'Vitamin K', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Vitamin K (mcg), without unit. Standard daily value is 120 mcg', 'nflc_el' )
        ]
    );

    $this->add_control(
        'vitamin_b1',
        [
            'label' => esc_html__( 'Vitamin B1 (Thiamin)', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Vitamin B1 (Thiamin) (mg), without unit. Standard daily value is 1.2 mg', 'nflc_el' )
        ]
    );

    $this->add_control(
        'vitamin_b2',
        [
            'label' => esc_html__( 'Vitamin B2 (Riboflavin)', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Vitamin B2 (Riboflavin) (mg), without unit. Standard daily value is 1.3 mg', 'nflc_el' )
        ]
    );

    $this->add_control(
        'vitamin_b3',
        [
            'label' => esc_html__( 'Vitamin B3 (Niacin)', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Vitamin B3 (Niacin) (mg), without unit. Standard daily value is 16 mg', 'nflc_el' )
        ]
    );

    $this->add_control(
        'vitamin_b6',
        [
            'label' => esc_html__( 'Vitamin B6 (Pyridoxine)', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Vitamin B6 (Pyridoxine) (mg), without unit. Standard daily value is 1.7 mg', 'nflc_el' )
        ]
    );

    $this->add_control(
        'folate',
        [
            'label' => esc_html__( 'Folate', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Folate (mcg), without unit. Standard daily value is 400 mcg', 'nflc_el' )
        ]
    );

    $this->add_control(
        'vitamin_b12',
        [
            'label' => esc_html__( 'Vitamin B12 (Cobalamine)', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Vitamin B12 (Cobalamine) (mcg), without unit. Standard daily value is 2.4 mcg', 'nflc_el' )
        ]
    );

    $this->add_control(
        'biotin',
        [
            'label' => esc_html__( 'Biotin', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Biotin (mcg), without unit. Standard daily value is 30 mcg', 'nflc_el' )
        ]
    );

    $this->add_control(
        'choline',
        [
            'label' => esc_html__( 'Choline', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Choline (mg), without unit. Standard daily value is 550 mg', 'nflc_el' )
        ]
    );

    $this->add_control(
        'vitamin_b5',
        [
            'label' => esc_html__( 'Vitamin B5 (Pantothenic acid)', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Vitamin B5 (Pantothenic acid) (mg), without unit. Standard daily value is 5 mg', 'nflc_el' )
        ]
    );

    $this->add_control(
        'phosphorus',
        [
            'label' => esc_html__( 'Phosphorus', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Phosphorus (mg), without unit. Standard daily value is 1250 mg', 'nflc_el' )
        ]
    );

    $this->add_control(
        'iodine',
        [
            'label' => esc_html__( 'Iodine', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Iodine (mcg), without unit. Standard daily value is 150 mcg', 'nflc_el' )
        ]
    );

    $this->add_control(
        'magnesium',
        [
            'label' => esc_html__( 'Magnesium', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Magnesium (mg), without unit. Standard daily value is 420 mg', 'nflc_el' )
        ]
    );

    $this->add_control(
        'zinc',
        [
            'label' => esc_html__( 'Zinc', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Zinc (mg), without unit. Standard daily value is 11 mg', 'nflc_el' )
        ]
    );

    $this->add_control(
        'selenium',
        [
            'label' => esc_html__( 'Selenium', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Selenium (mcg), without unit. Standard daily value is 55 mcg', 'nflc_el' )
        ]
    );

    $this->add_control(
        'copper',
        [
            'label' => esc_html__( 'Copper', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Copper (mg), without unit. Standard daily value is 0.9 mg', 'nflc_el' )
        ]
    );

    $this->add_control(
        'manganese',
        [
            'label' => esc_html__( 'Manganese', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Manganese (mg), without unit. Standard daily value is 2.3 mg', 'nflc_el' )
        ]
    );

    $this->add_control(
        'chromium',
        [
            'label' => esc_html__( 'Chromium', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Chromium (mcg), without unit. Standard daily value is 35 mcg', 'nflc_el' )
        ]
    );

    $this->add_control(
        'molybdenum',
        [
            'label' => esc_html__( 'Molybdenum', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Molybdenum (mcg), without unit. Standard daily value is 45 mcg', 'nflc_el' )
        ]
    );

    $this->add_control(
        'chloride',
        [
            'label' => esc_html__( 'Chloride', 'nflc_el' ),
            'type' => Controls_Manager::NUMBER,
            'dynamic' => [
                'active' => true,
            ],
            'default' => '',
            'min' => '0',
            'step' => '1',
            'description' => esc_html__( 'The amount of Chloride (mg), without unit. Standard daily value is 2300 mg', 'nflc_el' )
        ]
    );

    $this->add_control(
        'cust_nutrients_heading',
        [
            'label' => esc_html__( 'Add custom nutrients', 'nflc_el' ),
            'type' => Controls_Manager::HEADING,
            'separator' => 'before',
        ]
    );

    $this->add_control(
        'custom_nutrients',
            [
                'type' => Controls_Manager::REPEATER,
                'default' => [],
                'fields' => [
                    [
                        'name' => 'name',
                        'label' => esc_html__( 'Nutrient name', 'nflc_el' ),
                        'type' => Controls_Manager::TEXT,
                        'dynamic' => [
                            'active' => true,
                        ],
                        'description' => esc_html__( 'Provide a nutrient name. E.g. Power Protein', 'nflc_el' )
                    ],

                    [
                        'name' => 'unit',
                        'label' => esc_html__( 'Nutrient Quantity Unit', 'nflc_el' ),
                        'type' => Controls_Manager::TEXT,
                        'dynamic' => [
                            'active' => true,
                        ],
                        'description' => esc_html__( 'Provide a nutrient unit. E.g. mg', 'nflc_el' )
                    ],

                    [
                        'name' => 'amt',
                        'label' => esc_html__( 'Amount per serving', 'nflc_el' ),
                        'type' => Controls_Manager::NUMBER,
                        'dynamic' => [
                            'active' => true,
                        ],
                        'default' => '',
                        'min' => '0',
                        'step' => '1',
                        'description' => esc_html__( 'Provide amount per serving (without unit). E.g. 20', 'nflc_el' )
                    ],

                    [
                        'name' => 'sv',
                        'label' => esc_html__( 'Standard daily value', 'nflc_el' ),
                        'type' => Controls_Manager::NUMBER,
                        'dynamic' => [
                            'active' => true,
                        ],
                        'default' => '',
                        'min' => '0',
                        'step' => '1',
                        'description' => esc_html__( 'Provide standard daily value of Nutrient (without unit). E.g. 200', 'nflc_el' )
                    ],

                    [
                        'name' => 'level',
                        'label' => esc_html__( 'Nutrient indent level', 'nflc_el' ),
                        'type' => Controls_Manager::SELECT,
                        'options' => [
                            '0' => __( 'Level 0', 'nflc_el' ),
                            '1' => __( 'Level 1', 'nflc_el' ),
                            '2' => __( 'Level 2', 'nflc_el' ),
                            '3' => __( 'Level 3', 'nflc_el' )
                        ],
                    'default' => '',
                    'description' => esc_html__( 'Select indent level for Nutrient entry in table.', 'nflc_el' ),
                    ],

                    [
                        'name' => 'text_style',
                        'label' => esc_html__( 'Nutrient text style', 'nflc_el' ),
                        'type' => Controls_Manager::SELECT,
                        'options' => [
                        'normal' => __( 'Normal', 'nflc_el' ),
                        'bold' => __( 'Bold', 'nflc_el' ),
                    ],
                    'default' => '',
                    'description' => esc_html__( 'Select text style for the nutrient entry.', 'nflc_el' )
                ]
            ]
        ]
    );

    $this->end_controls_section();

    $this->start_controls_section(
        'section_nutrition_facts_title',
        [
            'label' => __('Nutrition Table', 'nflc_el'),
            'tab' => Controls_Manager::TAB_STYLE,
            'show_label' => false,
        ]
    );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'global_txt',
                'label' => __( 'Table global typography', 'nflc_el' ),
                'label_block' => true,
                'selector' => '{{WRAPPER}} .nutrition-table'
            ]
        );

        $this->add_responsive_control(
            'nf_title_margin',
            [
                'label' => __( 'Title margin', 'nflc_el' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px','em', 'rem' ],
                'selectors' => [
                    '{{WRAPPER}} .nt-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        );


        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'nt_title_txt',
                'label' => __( 'Title typography', 'nflc_el' ),
                'label_block' => true,
                'selector' => '{{WRAPPER}} .nt-title'
            ]
        );

        $this->add_control(
        'nt_title_color',
            [
                'label' => __( 'Title color', 'nflc_el' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [ '{{WRAPPER}} .nt-title' => 'color: {{VALUE}}']
            ]
        );

    $this->end_controls_section();

    $this->start_controls_section(
        'section_serving_per_cont',
        [
            'label' => __('Serving per container', 'nflc_el'),
            'tab' => Controls_Manager::TAB_STYLE,
            'show_label' => false,
        ]
    );

        $this->add_responsive_control(
            'serving_per_cont_margin',
            [
                'label' => __( 'Serving per container margin', 'nflc_el' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px','em', 'rem' ],
                'selectors' => [
                    '{{WRAPPER}} .serving-per-cont' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'serving_per_cont_txt',
                'label' => __( 'Typography', 'nflc_el' ),
                'label_block' => true,
                'selector' => '{{WRAPPER}} .serving-per-cont'
            ]
        );

        $this->add_control(
        'serving_per_cont_color',
            [
                'label' => __( 'Serving per container color', 'nflc_el' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [ '{{WRAPPER}} .serving-per-cont' => 'color: {{VALUE}}']
            ]
        );

    $this->end_controls_section();

    $this->start_controls_section(
        'section_serving_size',
        [
            'label' => __('Serving size', 'nflc_el'),
            'tab' => Controls_Manager::TAB_STYLE,
            'show_label' => false,
        ]
    ); 


        $this->add_responsive_control(
            'serving_size_margin',
            [
                'label' => __( 'Serving size margin', 'nflc_el' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px','em', 'rem' ],
                'selectors' => [
                    '{{WRAPPER}} .serving-size' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        ); 

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'serving_size_txt',
                'label' => __( 'Serving size typography', 'nflc_el' ),
                'label_block' => true,
                'selector' => '{{WRAPPER}} .serving-size'
            ]
        );

        $this->add_control(
        'serving_size_color',
            [
                'label' => __( 'Serving size color', 'nflc_el' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [ '{{WRAPPER}} .serving-size' => 'color: {{VALUE}}']
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_amt_per_serving',
            [
                'label' => __('Amount per serving', 'nflc_el'),
                'tab' => Controls_Manager::TAB_STYLE,
                'show_label' => false,
            ]
        ); 

        $this->add_responsive_control(
            'amt_per_serving_margin',
            [
                'label' => __( 'Amount per serving margin', 'nflc_el' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px','em', 'rem' ],
                'selectors' => [
                    '{{WRAPPER}} .amount-per-serving' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        ); 

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'amt_per_serving_txt',
                'label' => __( 'Amount per serving typography', 'nflc_el' ),
                'label_block' => true,
                'selector' => '{{WRAPPER}} .amount-per-serving'
            ]
        );

        $this->add_control(
        'amt_per_serving_color',
            [
                'label' => __( 'Amount per serving color', 'nflc_el' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [ '{{WRAPPER}} .amount-per-serving' => 'color: {{VALUE}}']
            ]
        );

    $this->end_controls_section();

    $this->start_controls_section(
            'section_calories',
            [
                'label' => __('Calories', 'nflc_el'),
                'tab' => Controls_Manager::TAB_STYLE,
                'show_label' => false,
            ]
        ); 

        $this->add_responsive_control(
            'calories_margin',
            [
                'label' => __( 'Calories margin', 'nflc_el' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px','em', 'rem' ],
                'selectors' => [
                    '{{WRAPPER}} .calories' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        ); 

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'calories_txt',
                'label' => __( 'Calories typography', 'nflc_el' ),
                'label_block' => true,
                'selector' => '{{WRAPPER}} .calories'
            ]
        );

        $this->add_control(
        'calories_color',
            [
                'label' => __( 'Calories color', 'nflc_el' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [ '{{WRAPPER}} .calories' => 'color: {{VALUE}}']
            ]
        );

    $this->end_controls_section();

   $this->start_controls_section(
            'section_extra_notes',
            [
                'label' => __('Extra notes', 'nflc_el'),
                'tab' => Controls_Manager::TAB_STYLE,
                'show_label' => false,
            ]
        ); 

        $this->add_responsive_control(
            'extra_notes_margin',
            [
                'label' => __( 'Extra notes margin', 'nflc_el' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px','em', 'rem' ],
                'selectors' => [
                    '{{WRAPPER}} .nt-footer' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        ); 

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'extra_notes_txt',
                'label' => __( 'Extra notes typography', 'nflc_el' ),
                'label_block' => true,
                'selector' => '{{WRAPPER}} .nt-footer'
            ]
        );

        $this->add_control(
        'extra_notes_color',
            [
                'label' => __( 'Extra notes color', 'nflc_el' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [ '{{WRAPPER}} .nt-footer' => 'color: {{VALUE}}']
            ]
        );

    $this->end_controls_section();    

}

    // The nflc function
        function nflc_el( $atts, $content = null ) {
            extract( shortcode_atts( array(
                'display_style'     => 'std',
                
                // Nutrition facts
                'serving_per_cont'  => '',
                'serving_size'      => '',
                'calories'          => '',
                'nutri_heading'     => __( 'Nutrition Facts', 'nflc_el' ),
                'extra_notes'       => __( '* The % Daily Value (DV) tells you how much a nutrient in a serving of food contributes to a daily diet. 2,000 calories a day is used for general nutrition advice.', 'nflc_el' ),
                'show_dv'           => false,
                'xclass'            => '',
                'custom_nutrients'  => '',

                // Nutrients
                'total_fat'         => '',
                'saturated_fat'     => '',
                'trans_fat'         => '',
                'polyunsat_fat'     => '',
                'monounsat_fat'     => '',
                'cholesterol'       => '',
                'sodium'            => '',
                'carbohydrate'      => '',
                'fiber'             => '',
                'sugar'             => '',
                'added_sugar'       => '',
                'sugar_alcohal'     => '',
                'protein'           => '',
                'vitamin_d'         => '',
                'calcium'           => '',
                'iron'              => '',
                'potassium'         => '',
                'vitamin_a'         => '',
                'vitamin_c'         => '',
                'vitamin_e'         => '',
                'vitamin_k'         => '',
                'vitamin_b1'        => '',
                'vitamin_b2'        => '',
                'vitamin_b3'        => '',
                'vitamin_b6'        => '',
                'folate'            => '',
                'vitamin_b12'       => '',
                'biotin'            => '',
                'vitamin_b5'        => '',
                'choline'           => '',
                'phosphorus'        => '',
                'iodine'            => '',
                'magnesium'         => '',
                'zinc'              => '',
                'selenium'          => '',
                'copper'            => '',
                'manganese'         => '',
                'chromium'          => '',
                'molybdenum'        => '',
                'chloride'          => ''
            ), $atts ) );

            // Nutrition values
            $nutrition_facts = apply_filters( 'nflc_nutrition_facts_list', array(
                array(
                    'id'            => 'total_fat',
                    'label'         => __( 'Total Fat', 'nflc_el' ),
                    'schema'        => 'fatContent',
                    'liclass'       => false,
                    'labelclass'    => 'font-bold',
                    'sv'            => apply_filters( 'total_fat_sv', 72 ),
                    'unit'          => 'g'
                ),
                array(
                    'id'            => 'saturated_fat',
                    'label'         => __( 'Saturated Fat', 'nflc_el' ),
                    'schema'        => 'saturatedFatContent',
                    'liclass'       => 'nt-sublevel-1',
                    'labelclass'    => false,
                    'sv'            => apply_filters( 'saturated_fat_sv', 20 ),
                    'unit'          => 'g'
                ),
                array(
                    'id'            => 'trans_fat',
                    'label'         => __( 'Trans Fat', 'nflc_el' ),
                    'schema'        => 'transFatContent',
                    'liclass'       => 'nt-sublevel-1',
                    'labelclass'    => false,
                    'sv'            => false,
                    'unit'          => 'g'
                ),
                array(
                    'id'            => 'polyunsat_fat',
                    'label'         => __( 'Polyunsaturated Fat', 'nflc_el' ),
                    'schema'        => 'unsaturatedFatContent',
                    'liclass'       => 'nt-sublevel-1',
                    'labelclass'    => false,
                    'sv'            => false,
                    'unit'          => 'g'
                ),
                array(
                    'id'            => 'monounsat_fat',
                    'label'         => __( 'Monounsaturated Fat', 'nflc_el' ),
                    'schema'        => 'unsaturatedFatContent',
                    'liclass'       => 'nt-sublevel-1',
                    'labelclass'    => false,
                    'sv'            => false,
                    'unit'          => 'g'
                ),
                array(
                    'id'            => 'cholesterol',
                    'label'         => __( 'Cholesterol', 'nflc_el' ),
                    'schema'        => 'cholesterolContent',
                    'liclass'       => '',
                    'labelclass'    => 'font-bold',
                    'sv'            => apply_filters( 'cholesterol_sv', 300 ),
                    'unit'          => 'mg'
                ),
                array(
                    'id'            => 'sodium',
                    'label'         => __( 'Sodium', 'nflc_el' ),
                    'schema'        => 'sodiumContent',
                    'liclass'       => '',
                    'labelclass'    => 'font-bold',
                    'sv'            => apply_filters( 'sodium_sv', 2300 ),
                    'unit'          => 'mg'
                ),
                array(
                    'id'            => 'carbohydrate',
                    'label'         => __( 'Total Carbohydrate', 'nflc_el' ),
                    'schema'        => 'carbohydrateContent',
                    'liclass'       => '',
                    'labelclass'    => 'font-bold',
                    'sv'            => apply_filters( 'carbohydrate_sv', 275 ),
                    'unit'          => 'g'
                ),
                array(
                    'id'            => 'fiber',
                    'label'         => __( 'Dietary Fiber', 'nflc_el' ),
                    'schema'        => 'fiberContent',
                    'liclass'       => 'nt-sublevel-1',
                    'labelclass'    => '',
                    'sv'            => apply_filters( 'fiber_sv', 28 ),
                    'unit'          => 'g'
                ),
                array(
                    'id'            => 'sugar',
                    'label'         => __( 'Total Sugars', 'nflc_el' ),
                    'schema'        => 'sugarContent',
                    'liclass'       => 'nt-sublevel-1',
                    'labelclass'    => '',
                    'sv'            => false,
                    'unit'          => 'g'
                ),
                array(
                    'id'            => 'added_sugar',
                    'label'         => __( 'Added Sugars', 'nflc_el' ),
                    'schema'        => false,
                    'liclass'       => 'nt-sublevel-2',
                    'labelclass'    => '',
                    'sv'            => apply_filters( 'added_sugar_sv', 50 ),
                    'unit'          => 'g'
                ),
                array(
                    'id'            => 'sugar_alcohal',
                    'label'         => __( 'Sugar Alcohal', 'nflc_el' ),
                    'schema'        => false,
                    'liclass'       => 'nt-sublevel-1',
                    'labelclass'    => '',
                    'sv'            => false,
                    'unit'          => 'g'
                ),
                array(
                    'id'            => 'protein',
                    'label'         => __( 'Protein', 'nflc_el' ),
                    'schema'        => 'proteinContent',
                    'liclass'       => 'nt-sep sep-8',
                    'labelclass'    => 'font-bold',
                    'sv'            => apply_filters( 'protein_sv', 50 ),
                    'unit'          => 'g'
                ),
                array(
                    'id'            => 'vitamin_d',
                    'label'         => __( 'Vitamin D (Cholecalciferol)', 'nflc_el' ),
                    'schema'        => false,
                    'liclass'       => false,
                    'labelclass'    => false,
                    'sv'            => apply_filters( 'vitamin_d_sv', 20 ),
                    'unit'          => 'mcg'
                ),
                array(
                    'id'            => 'calcium',
                    'label'         => __( 'Calcium', 'nflc_el' ),
                    'schema'        => false,
                    'liclass'       => false,
                    'labelclass'    => false,
                    'sv'            => apply_filters( 'calcium_sv', 1300 ),
                    'unit'          => 'mg'
                ),
                array(
                    'id'            => 'iron',
                    'label'         => __( 'Iron', 'nflc_el' ),
                    'schema'        => false,
                    'liclass'       => false,
                    'labelclass'    => false,
                    'sv'            => apply_filters( 'iron_sv', 18 ),
                    'unit'          => 'mg'
                ),
                array(
                    'id'            => 'potassium',
                    'label'         => __( 'Potassium', 'nflc_el' ),
                    'schema'        => false,
                    'liclass'       => false,
                    'labelclass'    => false,
                    'sv'            => apply_filters( 'potassium_sv', 4700 ),
                    'unit'          => 'mg'
                ),
                array(
                    'id'            => 'vitamin_a',
                    'label'         => __( 'Vitamin A', 'nflc_el' ),
                    'schema'        => false,
                    'liclass'       => false,
                    'labelclass'    => false,
                    'sv'            => apply_filters( 'vitamin_a_sv', 900 ),
                    'unit'          => 'mcg'
                ),
                array(
                    'id'            => 'vitamin_c',
                    'label'         => __( 'Vitamin C (Ascorbic Acid)', 'nflc_el' ),
                    'schema'        => false,
                    'liclass'       => false,
                    'labelclass'    => false,
                    'sv'            => apply_filters( 'vitamin_c_sv', 90 ),
                    'unit'          => 'mg'
                ),
                array(
                    'id'            => 'vitamin_e',
                    'label'         => __( 'Vitamin E (Tocopherol)', 'nflc_el' ),
                    'schema'        => false,
                    'liclass'       => false,
                    'labelclass'    => false,
                    'sv'            => apply_filters( 'vitamin_e_sv', 15 ),
                    'unit'          => 'mg'
                ),
                array(
                    'id'            => 'vitamin_k',
                    'label'         => __( 'Vitamin K', 'nflc_el' ),
                    'schema'        => false,
                    'liclass'       => false,
                    'labelclass'    => false,
                    'sv'            => apply_filters( 'vitamin_k_sv', 120 ),
                    'unit'          => 'mcg'
                ),
                array(
                    'id'            => 'vitamin_b1',
                    'label'         => __( 'Vitamin B1 (Thiamin)', 'nflc_el' ),
                    'schema'        => false,
                    'liclass'       => false,
                    'labelclass'    => false,
                    'sv'            => apply_filters( 'vitamin_b1_sv', 1.2 ),
                    'unit'          => 'mg'
                ),
                array(
                    'id'            => 'vitamin_b2',
                    'label'         => __( 'Vitamin B2 (Riboflavin)', 'nflc_el' ),
                    'schema'        => false,
                    'liclass'       => false,
                    'labelclass'    => false,
                    'sv'            => apply_filters( 'vitamin_b2_sv', 1.3 ),
                    'unit'          => 'mg'
                ),
                array(
                    'id'            => 'vitamin_b3',
                    'label'         => __( 'Vitamin B3 (Niacin)', 'nflc_el' ),
                    'schema'        => false,
                    'liclass'       => false,
                    'labelclass'    => false,
                    'sv'            => apply_filters( 'vitamin_b3_sv', 16 ),
                    'unit'          => 'mg'
                ),
                array(
                    'id'            => 'vitamin_b6',
                    'label'         => __( 'Vitamin B6 (Pyridoxine)', 'nflc_el' ),
                    'schema'        => false,
                    'liclass'       => false,
                    'labelclass'    => false,
                    'sv'            => apply_filters( 'vitamin_b6_sv', 1.7 ),
                    'unit'          => 'mg'
                ),
                array(
                    'id'            => 'folate',
                    'label'         => __( 'Folate', 'nflc_el' ),
                    'schema'        => false,
                    'liclass'       => false,
                    'labelclass'    => false,
                    'sv'            => apply_filters( 'folate_sv', 400 ),
                    'unit'          => 'mcg'
                ),
                array(
                    'id'            => 'vitamin_b12',
                    'label'         => __( 'Vitamin B12 (Cobalamine)', 'nflc_el' ),
                    'schema'        => false,
                    'liclass'       => false,
                    'labelclass'    => false,
                    'sv'            => apply_filters( 'vitamin_b12_sv', 2.4 ),
                    'unit'          => 'mcg'
                ),
                array(
                    'id'            => 'biotin',
                    'label'         => __( 'Biotin', 'nflc_el' ),
                    'schema'        => false,
                    'liclass'       => false,
                    'labelclass'    => false,
                    'sv'            => apply_filters( 'biotin_sv', 30 ),
                    'unit'          => 'mcg'
                ),
                array(
                    'id'            => 'vitamin_b5',
                    'label'         => __( 'Vitamin B5 (Pantothenic acid)', 'nflc_el' ),
                    'schema'        => false,
                    'liclass'       => false,
                    'labelclass'    => false,
                    'sv'            => apply_filters( 'vitamin_b5_sv', 5 ),
                    'unit'          => 'mg'
                ),
                array(
                    'id'            => 'choline',
                    'label'         => __( 'Choline', 'nflc_el' ),
                    'schema'        => false,
                    'liclass'       => false,
                    'labelclass'    => false,
                    'sv'            => apply_filters( 'choline_sv', 550 ),
                    'unit'          => 'mg'
                ),
                array(
                    'id'            => 'phosphorus',
                    'label'         => __( 'Phosphorus', 'nflc_el' ),
                    'schema'        => false,
                    'liclass'       => false,
                    'labelclass'    => false,
                    'sv'            => apply_filters( 'phosphorus_sv', 1250 ),
                    'unit'          => 'mg'
                ),
                array(
                    'id'            => 'iodine',
                    'label'         => __( 'Iodine', 'nflc_el' ),
                    'schema'        => false,
                    'liclass'       => false,
                    'labelclass'    => false,
                    'sv'            => apply_filters( 'iodine_sv', 150 ),
                    'unit'          => 'mcg'
                ),
                array(
                    'id'            => 'magnesium',
                    'label'         => __( 'Magnesium', 'nflc_el' ),
                    'schema'        => false,
                    'liclass'       => false,
                    'labelclass'    => false,
                    'sv'            => apply_filters( 'magnesium_sv', 420 ),
                    'unit'          => 'mg'
                ),
                array(
                    'id'            => 'zinc',
                    'label'         => __( 'Zinc', 'nflc_el' ),
                    'schema'        => false,
                    'liclass'       => false,
                    'labelclass'    => false,
                    'sv'            => apply_filters( 'zinc_sv', 11 ),
                    'unit'          => 'mg'
                ),
                array(
                    'id'            => 'selenium',
                    'label'         => __( 'Selenium', 'nflc_el' ),
                    'schema'        => false,
                    'liclass'       => false,
                    'labelclass'    => false,
                    'sv'            => apply_filters( 'selenium_sv', 55 ),
                    'unit'          => 'mcg'
                ),
                array(
                    'id'            => 'copper',
                    'label'         => __( 'Copper', 'nflc_el' ),
                    'schema'        => false,
                    'liclass'       => false,
                    'labelclass'    => false,
                    'sv'            => apply_filters( 'copper_sv', .9 ),
                    'unit'          => 'mg'
                ),
                array(
                    'id'            => 'manganese',
                    'label'         => __( 'Manganese', 'nflc_el' ),
                    'schema'        => false,
                    'liclass'       => false,
                    'labelclass'    => false,
                    'sv'            => apply_filters( 'manganese_sv', 2.3 ),
                    'unit'          => 'mg'
                ),
                array(
                    'id'            => 'chromium',
                    'label'         => __( 'Chromium', 'nflc_el' ),
                    'schema'        => false,
                    'liclass'       => false,
                    'labelclass'    => false,
                    'sv'            => apply_filters( 'chromium_sv', 35 ),
                    'unit'          => 'mcg'
                ),
                array(
                    'id'            => 'molybdenum',
                    'label'         => __( 'Molybdenum', 'nflc_el' ),
                    'schema'        => false,
                    'liclass'       => false,
                    'labelclass'    => false,
                    'sv'            => apply_filters( 'molybdenum_sv', 45 ),
                    'unit'          => 'mcg'
                ),
                array(
                    'id'            => 'chloride',
                    'label'         => __( 'Chloride', 'nflc_el' ),
                    'schema'        => false,
                    'liclass'       => 'nt-sep',
                    'labelclass'    => false,
                    'sv'            => apply_filters( 'chloride_sv', 2300 ),
                    'unit'          => 'mg'
                )
            ) );

            ob_start();

            $template_path = apply_filters( 'nflc_template_path', '/nflc-el-templates/' );

            if ( locate_template( $template_path . 'default.php' ) ) {
                require( get_stylesheet_directory() . $template_path . 'default.php' );
            }
            else {
                require( dirname( __FILE__ ) . $template_path . 'default.php' );
            }

            $out = ob_get_contents();

            ob_end_clean();

            return $out;

        }

    protected function render() {
        $settings = $this->get_settings_for_display();
        echo $this->nflc_el( $settings );
    }

    protected function content_template() {
    }
}