<?php
/**
 * Plugin Name: Nutrition Facts Label Creator for Elementor
 * Author:      SaurabhSharma
 * Author URI: 	http://codecanyon.net/user/saurabhsharma
 * Version:     1.0.0
 * Text Domain: nflc_el
 * Domain Path: /languages/
 * Description: An Elementor addon for creating Nutrition Facts Label.
 * Elementor tested up to: 3.13.0
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Nutrition_Facts_Label_Creator_El' ) ) {
    /**
     * Main Nutrition_Facts_Label_Creator_El Class
     *
     */
    final class Nutrition_Facts_Label_Creator_El {


        private static $instance;

        /**
         * Main Nutrition_Facts_Label_Creator_El Instance
         *
         */
        public static function instance() {

            if ( ! isset( self::$instance ) && ! ( self::$instance instanceof Nutrition_Facts_Label_Creator_El ) ) {

                self::$instance = new Nutrition_Facts_Label_Creator_El;

                self::$instance->nflc_el_hooks();

            }
            return self::$instance;
        }

        /**
         * Throw error on object clone
         *
         */
        public function __clone() {
            // Cloning instances of the class is forbidden
            _doing_it_wrong( __FUNCTION__, __( 'Not allowed.', 'nflc_el' ), '1.0' );
        }

        /**
         * Disable unserializing of the class
         *
         */
        public function __wakeup() {
            // Unserializing instances of the class is forbidden
            _doing_it_wrong( __FUNCTION__, __( 'Unserializing forbidden.', 'nflc_el' ), '1.0' );
        }


        /**
         * Load Plugin Text Domain
         *
         */
        public function load_plugin_textdomain() {

            $lang_dir = apply_filters( 'nflc_el_lang_dir', trailingslashit( plugin_dir_path(__FILE__) . 'languages' ) );

            // Native WordPress plugin locale filter
            $locale = apply_filters( 'plugin_locale', get_locale(), 'nflc_el' );
            $mofile = sprintf( '%1$s-%2$s.mo', 'nflc_el', $locale );

            // Paths to current locale file
            $mofile_local = $lang_dir . $mofile;

            if ( file_exists( $mofile_local ) ) {
                // wp-content/plugins/nutrition-facts-label-creator-el-el/languages/ folder
                load_textdomain( 'nflc_el', $mofile_local );
            }
            else {
                // Load default language files
                load_plugin_textdomain( 'nflc_el', false, $lang_dir );
            }

            return false;
        }

        /**
         * Setup the default hooks and actions
         */
        private function nflc_el_hooks() {

            add_action( 'plugins_loaded', array( self::$instance, 'load_plugin_textdomain' ) );

            add_action( 'elementor/widgets/widgets_registered', array( self::$instance, 'include_widgets') );

            add_action( 'elementor/frontend/after_register_styles', array( self::$instance, 'register_frontend_styles' ), 10 );

            add_action( 'elementor/frontend/after_enqueue_styles', array( self::$instance, 'enqueue_frontend_styles' ), 10 );

            add_action( 'admin_notices',  array( self::$instance, 'nflc_el_install_notice' ) );


        }


        public function include_widgets( $widgets_manager ) {
            require_once trailingslashit( plugin_dir_path( __FILE__ ) ) . 'includes/widget-nflc-el.php';
            $widgets_manager->register_widget_type( new \Nutrition_Facts_Label_Creator_El\Widgets\Widget_Nutrition_Facts_Label_Creator_El() );
        }


        /**
         * Load Frontend Styles
         *
         */
        public function register_frontend_styles() {

                wp_register_style( 'nflc-el-plugin-css', plugin_dir_url( __FILE__ ) . 'assets/css/nflc_el_frontend.css', array(), null );

                // RTL CSS
                if ( is_rtl() ) {
                    wp_register_style( 'nflc-el-plugin-rtl', plugin_dir_url( __FILE__ ) . 'assets/css/rtl_nflc_el_frontend.css', array(), null );
                }

        }

        // Load Frontend Styles
        public function enqueue_frontend_styles() {

            wp_enqueue_style( 'nflc-el-plugin-css' );


            if ( is_rtl() ) {
                wp_enqueue_style( 'nflc-el-plugin-rtl' );
            }

        }

        // Show notice if Elementor not installed
        function nflc_el_install_notice() {
            if ( ! defined( 'ELEMENTOR_PLUGIN_BASE' ) ) {
                echo sprintf( '<div class="error"><p>%s</p></div>', esc_attr__( 'Nutrition Facts Label Creator requires Elementor Page Builder. Kindly install and activate Elementor plugin.', 'nflc_el' ) );
            }
            else {
                return;
            }
        }
    }
} // If not class exists

/**
 * Generate Instance
 */
function nflc_el() {
    return Nutrition_Facts_Label_Creator_El::instance();
}

nflc_el();